You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-dev@db.apache.org by "Kathey Marsden (JIRA)" <ji...@apache.org> on 2013/10/24 02:05:42 UTC

[jira] [Created] (DERBY-6392) Optimizer slowdown from 10.2 to 10.3 (masked by DERBY-2130)

Kathey Marsden created DERBY-6392:
-------------------------------------

             Summary: Optimizer slowdown from 10.2 to 10.3 (masked by DERBY-2130)
                 Key: DERBY-6392
                 URL: https://issues.apache.org/jira/browse/DERBY-6392
             Project: Derby
          Issue Type: Bug
          Components: SQL
    Affects Versions: 10.10.1.1, 10.3.3.1, 10.4.2.1, 10.5.3.1, 10.6.2.2, 10.7.1.4, 10.8.3.1, 10.9.2.2, 10.11.0.0
         Environment: After the DERBY-2130 fix in trunk (10.11) I noticed that the repro attached to the issue (repro.sql) ran significantly slower on 10.11  vs  10.1  or  10.2  with the patch.  I tried the patch with 10.3 and found that the query ran slower there.  
10.1  - 13 seconds
10.2  with patch - 10 seconds
10.3 with patch - 69 seconds
10.11 with patch - 69 seconds

So there must have been some slowdown between 10.2 and 10.3 that was masked by the DERBY-2130 bug.

To reproduce on 10.3
Merge the DERBY-2130 fix from trunk
svn merge -x -b -c 1534465  https://svn.apache.org/repos/asf/db/derby/code/trunk

Run repro.sql attached to DERBY-2130

            Reporter: Kathey Marsden






--
This message was sent by Atlassian JIRA
(v6.1#6144)